package com.yc.ship.module.ota.dal.dataobject.tradelog;

import com.baomidou.mybatisplus.annotation.KeySequence;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.yc.ship.framework.tenant.core.db.TenantBaseDO;
import lombok.*;

import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * 分销商交易日志 DO
 *
 * @author 管理员
 */
@TableName("ota_trade_log")
@KeySequence("ota_trade_log_seq") // 用于 Oracle、PostgreSQL、Kingbase、DB2、H2 数据库的主键自增。如果是 MySQL 等数据库，可不写。
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class TradeLogDO extends TenantBaseDO {

    /**
     * 主键
     */
    @TableId
    private Long id;
    /**
     * 操作人ID
     */
    private Long operatorId;
    /**
     * 操作人名字
     */
    private String operatorName;
    /**
     * 1 余额充值、2 预付购票、3 预付退款、4 余额购票、5余额退票
     */
    private Integer tradeType;
    /**
     * 交易时间
     */
    private LocalDateTime tradeTime;
    /**
     * 交易前余额
     */
    private BigDecimal beforeBalance;
    /**
     * 交易后余额
     */
    private BigDecimal afterBalance;
    /**
     * 交易金额
     */
    private BigDecimal tradeAmount;
    /**
     * 1  增加，2 减少
     */
    private Integer tradeMode;
    /**
     * 备注
     */
    private String remark;
    /**
     * 订单号
     */
    private String orderId;
    /**
     * 分销商id
     */
    private Long distributorId;

    @TableField(exist = false)
    private String orderNo;

    /**
     * 门店ID
     */
    private Long storeId;

    @TableField(exist = false)
    private String storeName;
}
