package com.yc.ship.module.resource.service.ship;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import com.yc.ship.module.resource.controller.admin.ship.vo.*;
import com.yc.ship.module.resource.dal.dataobject.ship.ResourceShipDO;
import com.yc.ship.framework.common.pojo.PageResult;
import com.yc.ship.framework.common.pojo.PageParam;
import com.yc.ship.framework.common.util.object.BeanUtils;

import com.yc.ship.module.resource.dal.mysql.ship.ResourceShipMapper;

import static com.yc.ship.framework.common.exception.util.ServiceExceptionUtil.exception;
import static com.yc.ship.module.resource.enums.ErrorCodeConstants.*;

/**
 * 资源管理-游轮管理 Service 实现类
 *
 * @author fycloud
 */
@Service
@Validated
public class ResourceShipServiceImpl implements ResourceShipService {

    @Resource
    private ResourceShipMapper shipMapper;

    @Override
    public Long createShip(ResourceShipSaveReqVO createReqVO) {
        // 插入
        ResourceShipDO ship = BeanUtils.toBean(createReqVO, ResourceShipDO.class);
        shipMapper.insert(ship);
        // 返回
        return ship.getId();
    }

    @Override
    public void updateShip(ResourceShipSaveReqVO updateReqVO) {
        // 校验存在
        validateShipExists(updateReqVO.getId());
        // 更新
        ResourceShipDO updateObj = BeanUtils.toBean(updateReqVO, ResourceShipDO.class);
        shipMapper.updateById(updateObj);
    }

    @Override
    public void deleteShip(Long id) {
        // 校验存在
        validateShipExists(id);
        // 删除
        shipMapper.deleteById(id);
    }

    private void validateShipExists(Long id) {
        if (shipMapper.selectById(id) == null) {
            throw exception(SHIP_NOT_EXISTS);
        }
    }

    @Override
    public ResourceShipDO getShip(Long id) {
        return shipMapper.selectById(id);
    }

    @Override
    public PageResult<ResourceShipDO> getShipPage(ResourceShipPageReqVO pageReqVO) {
        return shipMapper.selectPage(pageReqVO);
    }

    @Override
    public List<ResourceShipDO> getListSimple() {
        return shipMapper.selectList();
    }

    @Override
    public List<ResourceShipDO> getList(List<Long> ids) {
        if(ids.isEmpty()) {
            return Collections.emptyList();
        }
        return shipMapper.selectByIds(ids);
    }

}